pub fn verify_batch<Msg, HashToField, Point, Scalar, Rng>(
generators: &[Point],
message: &Msg,
auths: &[(usize, Point, Signature<Point, Scalar>)],
hash_to_field: HashToField,
rng: Rng,
) -> boolwhere
Msg: ?Sized,
Rng: RngCore + CryptoRng,
HashToField: FnMut(&Point, &Point, &Msg) -> Scalar,
Point: CofactorGroup + Group<Scalar = Scalar>,
Scalar: PrimeFieldBits,Expand description
Verify a bach of signatures over the same message, from different signing keys.
The group arithmetic uses generators[i] to produce
public keys. Each usize value i in auths indexes
generators[i] (i.e. generators[i] * sk == auths[i].1).
Generators passed in are assumed to be trusted (not small order).